from rich.table import Table
from rich.console import Console
from typing import Sequence

def fileprint_objects_as_table(tracked_objects: Sequence, output_file: str, frame_number: int): 
    """Displays tracked object attributes in a formatted table for debugging purposes.
    
    If `output_file` is specified, writes the table to the given file instead of printing to the console.
    """
    console = Console()
    table = Table(show_header=True, header_style="bold magenta")
    table.add_column("Id", style="yellow", justify="center")
    table.add_column("Age", justify="right")
    table.add_column("Hit Counter", justify="right")
    table.add_column("Last distance", justify="right")
    table.add_column("Init Id", justify="center")
    
    for obj in tracked_objects:
        table.add_row(
            str(obj.id),
            str(obj.age),
            str(obj.hit_counter),
            f"{obj.last_distance:.4f}",
            str(obj.initializing_id),
        )
    
    file_mode = 'w' if frame_number == 0 else 'a'
    with open(output_file, file_mode) as f:
        f.write(f"===============================\n")
        f.write(f"Frame {frame_number}\n")
        console = Console(file=f)
        console.print(table)
        f.write(f"===============================\n")

    
